@@ -13,20 +13,25 @@ from floodlight.vis.positions import plot_positions, plot_trajectories
 class XY:
     """Spatio-temporal data fragment. Core class of floodlight.
 
-    Attributes
+    Parameters
     ----------
     xy: np.ndarray
         Full data array containing x- and y-coordinates, where each player's coordinates
         occupy two consecutive columns.
-    x: np.ndarray
-        X-data array, where each player's x-coordinates occupy one column.
-    y: np.ndarray
-        Y-data array, where each player's y-coordinates occupy one column.
     framerate: int, optional
         Temporal resolution of data in frames per second/Hertz.
-    direction: str, optional
+    direction: {'lr', 'rl'}, optional
         Playing direction of players in data fragment, should be either
         'lr' (left-to-right) or 'rl' (right-to-left).
+
+    Attributes
+    ----------
+    x: np.array
+        X-data array, where each player's x-coordinates occupy one column.
+    y: np.array
+        Y-data array, where each player's y-coordinates occupy one column.
+    N: int
+        The object's number of players.
     """
 
     xy: np.ndarray
@@ -46,7 +51,15 @@ class XY:
         self.xy[key] = value
 
     @property
-    def x(self):
+    def N(self) -> int:
+        n_columns = self.xy.shape[1]
+        if (n_columns % 2) != 0:
+            raise ValueError(f"XY has an odd number of columns ({n_columns})")
+        return n_columns // 2
+
+    @property
+    def x(self) -> np.array:
+        """X-data array, where each player's x-coordinates occupy one column."""
         return self.xy[:, ::2]
 
     @x.setter
@@ -54,21 +67,14 @@ class XY:
         self.xy[:, ::2] = x_data
 
     @property
-    def y(self):
+    def y(self) -> np.array:
+        """Y-data array, where each player's y-coordinates occupy one column."""
         return self.xy[:, 1::2]
 
     @y.setter
     def y(self, y_data: np.ndarray):
         self.xy[:, 1::2] = y_data
 
-    @property
-    def N(self) -> int:
-        """Returns the object's number of players."""
-        n_columns = self.xy.shape[1]
-        if (n_columns % 2) != 0:
-            raise ValueError(f"XY has an odd number of columns ({n_columns})")
-        return n_columns // 2
-
     def frame(self, t: int) -> np.ndarray:
         """Returns data for given frame *t*.
 
@@ -303,36 +309,8 @@ class XY:
 
         Examples
         --------
-        >>> import matplotlib.pyplot as plt
-        >>> import numpy as np
-        >>> from floodlight.core.pitch import Pitch
-        >>> from floodlight.core.xy import XY
-        >>> # positions
-        >>> pos = np.array(
-        >>>     [[35,5,35,63,25,25,25,50],
-        >>>     [45,10,45,55,35,20,35,45],
-        >>>     [55,10,55,55,45,20,45,45],
-        >>>     [88.5,20,88.5,30,88.5,40,88.5,50]])
-        >>> xy_pos = XY(pos) # create XY object
-        >>> # create Pitch object
-        >>> football_pitch = Pitch(xlim=(0,105), ylim=(0, 68), unit="m",
-        >>> sport="football")
-        >>> # create matplotlib.axes
-        >>> ax = plt.subplots()[1]
-        >>> # plot pitch on ax
-        >>> football_pitch.plot(color_scheme="standard", ax=ax)
-
-        >>> # plot positions on ax
-        >>> xy_pos.plot(plot_type="positions", t=0, ax=ax)
-        >>> plt.show()
-
-        .. image:: ../../_img/positions_example.png
-
-        >>> # plot trajectories from frame 0 to 4 on ax
-        >>> xy_pos.plot(plot_type="trajectories", t=(0,4), ball= False, ax=ax)
-        >>> plt.show()
-
-        .. image:: ../../_img/trajectories_example.png
+        - :ref:`Positions plot <positions-plot-label>`
+        - :ref:`Trajectories plot <trajectories-plot-label>`
 
         """
 
